Module assembly

Module assembly 

Functions

assemble_combined
Assemble a combined document from spec files by merging all children under a <cmb:spec> root element.
assemble_combined_string
Assemble combined document and return it as an XML string.