Structs
- Artifact
Coverage - Coverage info for a single artifact mapping.
- Coverage
Report - Coverage report for a spec.
- Covered
Range - A range of lines covered by an artifact mapping.
- File
Coverage - Per-file code coverage analysis.
- Uncovered
Range - A contiguous range of uncovered non-whitespace lines.
Enums
- Coverage
Strength - Coverage strength classification based on line count.
- Spec
Coverage - Spec node coverage status.
Functions
- analyze_
coverage - Analyze spec and code coverage.
- classify_
strength - Classify coverage strength by line count.
- count_
non_ whitespace_ lines - Filter out whitespace-only lines from a range and return the non-whitespace line count.