Module drift

Module drift 

Structs

DriftReport
Overall drift report for a spec.
MappingDrift
Result of drift detection for a single mapping.

Enums

DriftStatus
Result of drift detection for a single artifact mapping.

Functions

check_drift
Check for drift across all artifact mappings in a spec.
hashes_match
Compare two hashes and return whether they match.