execute_query

Function execute_query 

pub fn execute_query(
    spec_dir: &Path,
    xpath_expr: &str,
    mode: QueryMode,
) -> Result<QueryResult, Error>
Execute an XPath query against a spec’s combined document.

Assembles a combined document from the spec files, registers all clayers namespace prefixes, and evaluates the XPath expression.

Errors

Returns an error if the spec cannot be assembled or the XPath is invalid.