Module assembly
clayers_
spec
0.2.0
Module assembly
Module Items
Functions
In crate clayers_
spec
clayers_spec
Module
assembly
Functions

assemble_
combined
Assemble a combined document from spec files by merging all children under a
<cmb:spec>
root element.
assemble_
combined_
string
Assemble combined document and return it as an XML string.